@@ -4,7 +4,7 @@ import json
 import tomlkit
 
 from .models import (
-    DataView, Hash, Requires,
+    DataView, Hash, Requires, PipfileSection, Pipenv,
     PackageCollection, ScriptCollection, SourceCollection,
 )
 
@@ -15,6 +15,8 @@ PIPFILE_SECTIONS = {
     "dev-packages": PackageCollection,
     "requires": Requires,
     "scripts": ScriptCollection,
+    "pipfile":  PipfileSection,
+    "pipenv": Pipenv
 }
 
 DEFAULT_SOURCE_TOML = """\
@@ -24,7 +26,6 @@ url = "https://pypi.org/simple"
 verify_ssl = true
 """
 
-
 class Pipfile(DataView):
     """Representation of a Pipfile.
     """
@@ -42,6 +43,11 @@ class Pipfile(DataView):
                 continue
             klass.validate(data[key])
 
+        package_categories = set(data.keys()) - set(PIPFILE_SECTIONS.keys())        
+
+        for category in package_categories:
+            PackageCollection.validate(data[category])
+
     @classmethod
     def load(cls, f, encoding=None):
         content = f.read()
